@@ -30,25 +30,36 @@ def test_ordinal(test_input, expected):
 
 
 @pytest.mark.parametrize(
-    "test_input, expected",
+    "test_args, expected",
     [
-        (100, "100"),
-        (1000, "1,000"),
-        (10123, "10,123"),
-        (10311, "10,311"),
-        (1000000, "1,000,000"),
-        (1234567.25, "1,234,567.25"),
-        ("100", "100"),
-        ("1000", "1,000"),
-        ("10123", "10,123"),
-        ("10311", "10,311"),
-        ("1000000", "1,000,000"),
-        ("1234567.1234567", "1,234,567.1234567"),
-        (None, None),
+        ([100], "100"),
+        ([1000], "1,000"),
+        ([10123], "10,123"),
+        ([10311], "10,311"),
+        ([1000000], "1,000,000"),
+        ([1234567.25], "1,234,567.25"),
+        (["100"], "100"),
+        (["1000"], "1,000"),
+        (["10123"], "10,123"),
+        (["10311"], "10,311"),
+        (["1000000"], "1,000,000"),
+        (["1234567.1234567"], "1,234,567.1234567"),
+        ([None], None),
+        ([14308.40], "14,308.4"),
+        ([14308.40, None], "14,308.4"),
+        ([14308.40, 1], "14,308.4"),
+        ([14308.40, 2], "14,308.40"),
+        ([14308.40, 3], "14,308.400"),
+        ([1234.5454545], "1,234.5454545"),
+        ([1234.5454545, None], "1,234.5454545"),
+        ([1234.5454545, 1], "1,234.5"),
+        ([1234.5454545, 2], "1,234.55"),
+        ([1234.5454545, 3], "1,234.545"),
+        ([1234.5454545, 10], "1,234.5454545000"),
     ],
 )
-def test_intcomma(test_input, expected):
-    assert humanize.intcomma(test_input) == expected
+def test_intcomma(test_args, expected):
+    assert humanize.intcomma(*test_args) == expected
 
 
 def test_intword_powers():
@@ -86,6 +97,7 @@ def test_intword(test_args, expected):
 @pytest.mark.parametrize(
     "test_input, expected",
     [
+        (0, "zero"),
         (1, "one"),
         (2, "two"),
         (4, "four"),
